==> wicket-1.3.7-sources.jar: org/apache/wicket/ajax/markup/html/form/AjaxSubmitButton.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.ajax.markup.html.form;

import org.apache.wicket.markup.html.form.Button;
import org.apache.wicket.markup.html.form.Form;

/**
 * A button that submits the form via ajax. Since this button takes the form as a constructor
 * argument it does not need to be added to it unlike the {@link Button} component.
 * 
 * @since 1.2
 * 
 * @author Igor Vaynberg (ivaynberg)
 * @deprecated Use {@link AjaxButton} instead.
 */
public abstract class AjaxSubmitButton extends AjaxButton
{
	private static final long serialVersionUID = 1L;

	/**
	 * Construct.
	 * 
	 * @param id
	 * @deprecated Use {@link AjaxButton} instead.
	 */
	public AjaxSubmitButton(String id)
	{
		super(id);
	}

	/**
	 * Construct.
	 * 
	 * @param id
	 * @param form
	 * @deprecated Use {@link AjaxButton} instead.
	 */
	public AjaxSubmitButton(String id, final Form form)
	{
		super(id, form);
	}
}

==> wicket-1.4-rc4-sources.jar: org/apache/wicket/ajax/markup/html/form/AjaxSubmitButton.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.ajax.markup.html.form;

import org.apache.wicket.markup.html.form.Button;
import org.apache.wicket.markup.html.form.Form;

/**
 * A button that submits the form via ajax. Since this button takes the form as a constructor
 * argument it does not need to be added to it unlike the {@link Button} component.
 * 
 * @since 1.2
 * 
 * @author Igor Vaynberg (ivaynberg)
 * @deprecated Use {@link AjaxButton} instead.
 */
@Deprecated
public abstract class AjaxSubmitButton extends AjaxButton
{
	private static final long serialVersionUID = 1L;

	/**
	 * Construct.
	 * 
	 * @param id
	 * @deprecated Use {@link AjaxButton} instead.
	 */
	@Deprecated
	public AjaxSubmitButton(String id)
	{
		super(id);
	}

	/**
	 * Construct.
	 * 
	 * @param id
	 * @param form
	 * @deprecated Use {@link AjaxButton} instead.
	 */
	@Deprecated
	public AjaxSubmitButton(String id, final Form<?> form)
	{
		super(id, form);
	}
}
